#[macro_export] macro_rules!
show {
    ($($arg:expr),*) => {
        $(print!("{} ", $arg);)*
        println!("");
    };
    ($($arg:expr),*; $($a:tt)*) => {
        $(print!("{} ", $arg);)*
        println!("");
    };
}
